@@ -4,7 +4,7 @@
  * Gnome Crystal
  * application.cc 
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2004
  *
  * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
  *
@@ -115,15 +115,18 @@ void on_about()
 	char * authors[]={"Jean Bréfort",NULL};
 	char * documentors[] = {NULL};
 	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/pixmaps/gnome-crystal-logo.png", NULL);
-	char * translators = _(\
-"Jean Bréfort <jean.brefort@ac-dijon.fr>: French\n\
-Tigrux <tigrux@avantel.net>: Spanish\n\
-Costantino Ceoldo <inverness1@virgilio.it>: Italian"
-			);
+	char * translators = g_strconcat (
+			_("Jean Bréfort: French"), "\n",
+			_("Tigrux: Spanish"),"\n",
+			_("Costantino Ceoldo: Italian"), "\n",
+			_("Nikodem Kuznik: Polish"), NULL);
 	GtkWidget* about = gnome_about_new(_("Gnome Crystal"), VERSION,
 										_("(C) 1999-2004 by Jean Bréfort"),
 										_("Gnome Crystal is a lightweight crystal structures viewer for Gnome"),
 										(const gchar**) authors, (const gchar**) documentors, translators, pixbuf);
+	if (pixbuf != NULL)
+		g_object_unref (pixbuf);
+	g_free (translators);
 	gtk_widget_show_all(about);
 }
 
