@@ -4,7 +4,7 @@
  * Gnome Crystal
  * filesel.h 
  *
- * Copyright (C) 2001-2002
+ * Copyright (C) 2001-2003
  *
  * Developed by Jean Brfort <jean.brefort@ac-dijon.fr>
  *
@@ -27,7 +27,8 @@
 #ifndef GCRYSTAL_FILESEL_H
 #define GCRYSTAL_FILESEL_H
 
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include "document.h"
 
 class gcFileSel
@@ -38,7 +39,6 @@ public:
 
 	virtual void Destroy();
 	virtual bool Apply();
-	GtkWidget* GetWidget() {return (GtkWidget*)fsel;}
 	
 private:
 	GtkFileSelection* fsel;
